@@ -2,7 +2,7 @@ from photutils import EllipticalAperture, aperture_photometry
 
 __all__=["transform_xy_ellipse"]
 
-def transform_xy_ellipse(centerX, centerY, aAxis, bAxis, cubeObj):
+def transform_xy_ellipse(centerX, centerY, aAxis, bAxis, cubeModel):
     """ Update rectangle data widgets and image object attributes
     :param float centerX: center x coordinate
     :param float centerY: center y coordinate
@@ -13,17 +13,22 @@ def transform_xy_ellipse(centerX, centerY, aAxis, bAxis, cubeObj):
     :return list wValues: wavelenght list for each slice
     :return Aperture_Photometry aperture: aperture of the ellipse
     """
+    wValues = []
     fValues = []
     #Because it gets all the flux on a pixel, it needs to get the area of it rather
     #the sum of it
-    pixelArea = (cubeObj.cubeRAValue * 3600.) * (cubeObj.cubeDValue * 3600.)
+    pixelArea = (cubeModel.meta.wcsinfo.cdelt1 * 3600.) * (cubeModel.meta.wcsinfo.cdelt2 * 3600.)
 
-    position = [(centerX, centerY)]
+    #To correct the additional extend applied to the figure, the center cooridnates must
+    #be 1 pixel unit less
+    position = [(centerX-1, centerY-1)]
     aperture = EllipticalAperture(position,aAxis/2, bAxis/2)
-    for i in range(cubeObj.maxSlice):
-        phot_table = aperture_photometry(cubeObj.data_cube[i], aperture, method= 'exact')
+    d2w = cubeModel.meta.wcs.get_transform('detector', 'world')
+    for i in range(cubeModel.data.shape[0]):
+        phot_table = aperture_photometry(cubeModel.data[i], aperture, method= 'exact')
         fValues.append(phot_table['aperture_sum'][0]*pixelArea)
-
-    wValues = [((w+1) - cubeObj.cubeZCPix)*cubeObj.cubeWValue + cubeObj.cubeZCRVal for w in range(len(fValues))]
+        ra, dec, wavelength = d2w(1,1,i)
+        wValues.append(wavelength)
+    #wValues = [((w+1) - cubeModel.meta.wcsinfo.crpix3)*cubeModel.meta.wcsinfo.cdelt3 + cubeModel.meta.wcsinfo.crval3 for w in range(len(fValues))]
 
     return fValues, wValues, aperture
