@@ -3,7 +3,7 @@ Create the Widget structure for the item in the model data list widget
 """
 import sys
 from PyQt5 import QtCore, QtGui, QtWidgets
-from PyQt5.QtCore import pyqtSignal
+from PyQt5.QtCore import pyqtSignal, Qt
 from PyQt5.QtWidgets import *
 
 class modelListwidget(QtWidgets.QWidget):
@@ -13,5 +13,8 @@ class modelListwidget(QtWidgets.QWidget):
         super(modelListwidget, self).__init__(parent, **kwargs)
 
         self.label = QLabel(label_text)
+        font = self.label.font()
+        font.setPointSize(12)
+        self.label.setFont(font)
         plot_lay = QHBoxLayout(self)
         plot_lay.addWidget(self.label)
